demo_fit is an mcpfit object generated from the mcp_example("demo")
model and data with two chains of 1000 posterior draws and prior draws.
Format
An mcpfit object.
See also
mcp_example for the model and data used to create it,
and mcpfit-class for the structure and methods of fitted models.