Fits and Predictions given Draws and data
Usage
pp_eval(
object,
newdata = NULL,
summary = TRUE,
type = "fitted",
probs = TRUE,
rate = TRUE,
prior = FALSE,
dpar = "epred",
varying = TRUE,
arma = TRUE,
ndraws = NULL,
samples_format = "tidy",
scale = "response",
.include_fitted = FALSE,
nsamples = lifecycle::deprecated()
)Arguments
- object
An
mcpfitobject.- newdata
A
tibbleor adata.framecontaining predictors in the model. Weighted Gaussian predictions and log-likelihoods also require the weights column. IfNULL(default), the original data is used.- summary
Summarise at each x-value
- type
One of:
"fitted": return expected values. Whendparis the name of a dpar (e.g.,"mu"or"sigma"), the expected value for just this dpar is returned. See alsofitted()."predict": return predicted values (e.g.,y_predict = rnorm(N, y_fitted, sigma_fitted)forfamily = gaussian()). See alsopredict()."residuals": observed y-values minus the fitted values. See alsoresiduals()."loglik": return the log-likelihood for each sample for each data point. See alsolog_lik(). Requiresscale = "response".
- probs
Vector of quantiles. Only in effect when
summary == TRUE.- rate
Boolean. For binomial models, plot on raw data (
rate = FALSE) or response divided by number of trials (rate = TRUE). If FALSE, linear interpolation on trial number is used to infer trials at a particular x.- prior
TRUE/FALSE. Plot using prior samples? Useful for
mcp(..., sample = "both")- dpar
What distributional parameter to evaluate. This is only relevant when
type == "fitted". E.g.,"epred"(default): Expected value of the full model (orNULLfor compatibility with brms etc.)."mu": The central tendency which is often the mean after applying the link function."sigma": The standard deviation of the residuals."ar1","ar2","ma1","ma2", etc. depending on which AR or MA coefficient you want to evaluate.
- varying
One of:
TRUEAll varying effects (fit$pars$varying).FALSENo varying effects (c())."cp"or"predictor": All varying effects belonging to that part of the model.Character vector: Only include specified varying parameters - see
fit$pars$varying.
- arma
Whether to include AR and MA effects.
TRUECompute the GARMA residual recurrence. Requires the response variable innewdata.FALSEDisregard AR and MA effects. Forfamily = gaussian(),predict()uses onlysigmafor residuals.
- ndraws
Integer or
NULL. Number of posterior draws to return/summarise. If there are varying effects, this is the number of draws from each varying group.NULLmeans "all". Ignored if both areFALSE. More samples trade speed for accuracy.- samples_format
One of "tidy" or "matrix". Controls the output format when
summary == FALSE. See more under "value"- scale
One of
"response": return on the observed scale, i.e., after applying the inverse link function."linear": return on the parameter scale (where the linear trends are modelled). A linear scale is only applicable whentype == "fitted"anddparis notNULL.
- .include_fitted
Internal. Include fitted values with unsummarised predictions.
- nsamples
Deprecated. Use
ndrawsinstead.
Value
If
summary = TRUE: Atibblewith the posterior mean for each row innewdata, IfnewdataisNULL, the data infit$datais used.If
summary = FALSEandsamples_format = "tidy": Atidybayestibblewith all the posterior draws (Nd) evaluated at each row innewdata(Nn), i.e., withNd x Nnrows. If there are varying effects, the returned data is expanded with the relevant levels for each row.The return columns are:
Predictors from
newdata.Draw descriptors: ".chain", ".iteration", ".draw" (see the
posteriorandtidybayespackages), anddata_row, the row number in the evaluatednewdata.Draw values: one column for each parameter in the model.
The estimate. Either ".epred", ".prediction", ".residual", or ".loglik" (matching tidybayes/ggdist conventions).
If
summary = FALSEandsamples_format = "matrix": AnN_drawsXnrows(newdata)matrix with fitted/predicted values (depending ontype). This format is used bybrmsand it's useful asyrepinbayesplot::ppc_*functions.
Author
Jonas Kristoffer Lindeløv jonas@lindeloev.dk